@@ -13,7 +13,7 @@ impl ToSVG for Shape {
                 font_size,
                 font_weight,
             } => Ok(format!(
-                r#"<text x="{x}" y="{y}" {anchor} font-size="{size}" {weight} {style}>{text}</text>"#,
+                r#"<text x="{x}" y="{y}" {anchor} font-family="Arial" font-size="{size}" {weight} {style}>{text}</text>"#,
                 x = pos.x,
                 y = -pos.y,
                 anchor = align.to_svg()?,
@@ -149,9 +149,9 @@ impl ToSVG for TextAlign {
         Ok(format!(
             r#"text-anchor="{}""#,
             match self {
-                TextAlign::Left => "left",
+                TextAlign::Left => "start",
                 TextAlign::Center => "middle",
-                TextAlign::Right => "right",
+                TextAlign::Right => "end",
             }
         ))
     }
@@ -203,7 +203,7 @@ mod tests {
                 .with_align(TextAlign::Center),
         );
 
-        let text_svg = r#"<text x="-10" y="-10" text-anchor="middle" font-size="10" font-weight="bold" fill='rgba(255,0,0,1)' >hello world</text>"#;
+        let text_svg = r#"<text x="10" y="-10" text-anchor="middle" font-family="Arial" font-size="10" font-weight="bold" fill='rgba(255,0,0,1)' >hello world</text>"#;
         let drawing_svg = format!(r#"<svg viewBox="-0 -0 0 0">{}</svg>"#, text_svg);
 
         assert_eq!(drawing.shapes()[0].to_svg().unwrap(), text_svg);
@@ -218,7 +218,7 @@ mod tests {
                 .to(vec2(20., 20.))
                 .with_fill(Fill::Color(Color::U32(0xFF0000))),
         );
-        let line_svg = r#"<line x1="10" y1="10" x2="20" y2="20" fill='rgba(255,0,0,1)' />"#;
+        let line_svg = r#"<line x1="10" y1="-10" x2="20" y2="-20" fill='rgba(255,0,0,1)' />"#;
         let drawing_svg = format!(r#"<svg viewBox="-0 -0 0 0">{}</svg>"#, line_svg);
         assert_eq!(drawing.shapes()[0].to_svg().unwrap(), line_svg);
         assert_eq!(drawing.to_svg().unwrap(), drawing_svg);
